@@ -86,6 +86,16 @@ def get_headers():
     return open_json_file(file_path)
 
 
+def childs_page_return_right_login(response_page, smarsy_login):
+    """
+    Receive HTML page from login function and check we've got expected source
+    """
+    if smarsy_login in response_page:
+        return True
+    else:
+        raise ValueError('Invalid Smarsy Login')
+
+
 def login():
     """
     Perform login to Smarsy.
